@@ -5,13 +5,16 @@
 """
 from __future__ import annotations
 
-from io import BytesIO
-from pathlib import Path
+from typing import TYPE_CHECKING
 from warnings import warn
 
 from .docx_output import DocxContent
 from .docx_reader import DocxReader
 
+if TYPE_CHECKING:
+    from io import BytesIO
+    from pathlib import Path
+
 
 def docx2python(
     docx_filename: str | Path | BytesIO,
@@ -19,6 +22,7 @@ def docx2python(
     html: bool = False,
     paragraph_styles: bool = False,
     extract_image: bool | None = None,
+    duplicate_merged_cells: bool = False,
 ) -> DocxContent:
     """
     Unzip a docx file and extract contents.
@@ -30,6 +34,8 @@ def docx2python(
     :param paragraph_styles: prepend the paragraphs style (if any, else "") to each
         paragraph. This will only be useful with ``*_runs`` attributes.
     :param extract_image: bool, extract images from document (default True)
+    :param duplicate_merged_cells: bool, duplicate merged cells to return a mxn
+        nested list for each table (default False)
     :return: DocxContent object
     """
     if extract_image is not None:
@@ -40,7 +46,9 @@ def docx2python(
             + "``docx2python(filename).write_images(image_folder)``. Images files are "
             + "available as before with ``docx2text(filename).images`` attribute."
         )
-    docx_context = DocxReader(docx_filename, html, paragraph_styles)
+    docx_context = DocxReader(
+        docx_filename, html, paragraph_styles, duplicate_merged_cells
+    )
     docx_content = DocxContent(docx_context, locals())
     if image_folder:
         _ = docx_content.images
